;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "isearch-project" "20260101.600"
  "Incremental search through the whole project."
  '((emacs "27.1")
    (f     "0.20.0"))
  :url "https://github.com/jcs-elpa/isearch-project"
  :commit "e67c997c9b36690a8b1b7712ff1ba9664020d8b2"
  :revdesc "e67c997c9b36"
  :keywords '("convenience" "search")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
